import * as i0 from '@angular/core';
import { Injectable, Component, Input, EventEmitter, Output, ErrorHandler, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { map, distinctUntilChanged } from 'rxjs/operators';
import * as i1 from '@angular/common/http';
import { __decorate } from 'tslib';
import * as i5 from '@angular/common';
import { CommonModule } from '@angular/common';

const initialState = {
    ratingInfo: null,
    chips: [],
    progressiveFeedbackData: null
};
class DpwFeedbackWidgetService {
    constructor(http) {
        this.http = http;
        this.hasError = false;
        this.metaData = {};
        this.userFeedback = new BehaviorSubject(initialState);
        this.userFeedback$ = this.userFeedback.asObservable();
        this.ratingInfo$ = this.userFeedback$.pipe(map((state) => state.ratingInfo), distinctUntilChanged());
    }
    get currentState() {
        return this.userFeedback.getValue();
    }
    updateMetaData(data) {
        this.metaData = Object.assign(Object.assign({}, this.metaData), data);
    }
    updateUserFeedback(data) {
        this.userFeedback.next(Object.assign(Object.assign({}, this.currentState), data));
    }
    resetState() {
        this.userFeedback.next(initialState);
    }
    submitFeedback(reqBody) {
        return this.http.post('http://localhost:3600/api/feedback/users', reqBody);
    }
}
DpwFeedbackWidgetService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
DpwFeedbackWidgetService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetService, providedIn: "root" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: "root",
                }]
        }], ctorParameters: function () { return [{ type: i1.HttpClient }]; } });

const noop = () => { };
function isRequired(requiredType, size) {
    return (target, prop) => {
        const NG_ON_ONIT_NAME = "ngOnInit";
        /** ngOnInit might not be implemented by this component */
        const ngOnInitClone = target[NG_ON_ONIT_NAME];
        Object.defineProperty(target, NG_ON_ONIT_NAME, {
            value: function () {
                if (this[prop] == null) {
                    throw new Error(target.constructor.name +
                        `: @Input ${prop} is required, but was not provided`);
                }
                else if (requiredType && typeof this[prop] !== requiredType) {
                    throw new Error(target.constructor.name +
                        `: @Input ${prop} is expected to be a ${requiredType}, but ${typeof this[prop]} was provided`);
                }
                else if (size &&
                    typeof this[prop] === "string" &&
                    this[prop].length > size) {
                    throw new Error(target.constructor.name +
                        `: @Input '${prop}' can't be more than ${size} characters`);
                }
                // Calling the original ngOnInit with its original context
                (ngOnInitClone || noop).call(this);
            },
        });
    };
}

function isTypeOf(requiredType, limit) {
    return (target, prop, newVal) => {
        /** Whether the new value matches the required type */
        let isValidType = true;
        if (newVal) {
            if (requiredType === "array") {
                isValidType = newVal instanceof Array;
            }
            else {
                isValidType = typeof newVal === requiredType;
            }
            if (!isValidType) {
                throw new Error(target.constructor.name +
                    `: @Input '${prop}' is expected to be of type ${requiredType}, but type ${typeof newVal} was provided`);
            }
        }
        if (limit && typeof newVal === "string" && newVal.length > limit) {
            throw new Error(target.constructor.name +
                `: @Input '${prop}' can't be more than ${limit} characters`);
        }
        else if (limit && newVal instanceof Array && newVal.length > limit) {
            throw new Error(target.constructor.name +
                `: @Input '${prop}' length can't be more than ${limit}`);
        }
    };
}

function validateAgainst(fn) {
    return (target, prop) => {
        let _value = null;
        // Create new property with getter and setter
        Object.defineProperty(target, prop, {
            get() {
                return _value;
            },
            set: function (newVal) {
                _value = newVal;
                fn(target, prop, newVal);
            },
            configurable: true,
            enumerable: true,
        });
    };
}

const RATING_TYPE = {
    GOOD: "GOOD",
    AVERAGE: "AVERAGE",
    BAD: "BAD",
};
const DEFAULT_FEEDBACK_META_DATA = {
    feedbackBtnText: "Submit Feedback",
    showClose: true,
    thankYouHeading: "Thank You!",
    thankYouDescription: "We appriciate your feedback and response. Looking forward to serve you again.",
    thankYouBtnText: "Done",
    badRatingHeader: "What went wrong?",
    averageRatingHeader: "What went well?",
    goodRatingHeader: "What went well?",
    closeHandler: null,
    onSubmitFeedback: null,
    textareaLimit: 250,
};
const SMILEY_RATINGS = [
    {
        rating: 1,
        title: "Terrible",
        imgUrl: "assets/images/fw_terribleEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 2,
        title: "Bad",
        imgUrl: "assets/images/fw_badEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 3,
        title: "Okay",
        imgUrl: "assets/images/fw_okayEmoji.svg",
        type: RATING_TYPE.AVERAGE,
    },
    {
        rating: 4,
        title: "Good",
        imgUrl: "assets/images/fw_goodEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
    {
        rating: 5,
        title: "Amazing",
        imgUrl: "assets/images/fw_amazingEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
];
const STAR_RATINGS = [
    {
        rating: 1,
        title: "Very Bad",
        imgUrl: "assets/images/fw_terribleEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 2,
        title: "Bad",
        imgUrl: "assets/images/fw_badEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 3,
        title: "Okay",
        imgUrl: "assets/images/fw_okayEmoji.svg",
        type: RATING_TYPE.AVERAGE,
    },
    {
        rating: 4,
        title: "Good",
        imgUrl: "assets/images/fw_goodEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
    {
        rating: 5,
        title: "Excellent",
        imgUrl: "assets/images/fw_amazingEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
];

class FeedbackWidgetHeaderComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
}
FeedbackWidgetHeaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: FeedbackWidgetHeaderComponent, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Component });
FeedbackWidgetHeaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: FeedbackWidgetHeaderComponent, selector: "lib-feedback-widget-header", ngImport: i0, template: "<div class=\"fw-header-container\">\n  <p class=\"fw-header\">{{ fwService.metaData.header }}</p>\n  <p class=\"fw-sub-header\">{{ fwService.metaData.subHeader }}</p>\n  <img *ngIf=\"fwService.metaData.showClose\" class=\"fw-close-icon\" (click)=\"fwService.metaData.closeHandler()\" src=\"assets/images/fw_close_icon.svg\" />\n</div>\n", styles: [":host .fw-header-container .fw-header{font-weight:700;font-size:24px;line-height:33px}:host .fw-header-container .fw-sub-header{font-weight:400;font-size:15px;line-height:21px}:host .fw-header-container .fw-close-icon{position:absolute;top:10px;right:10px;width:21px;height:21px;cursor:pointer}\n"], directives: [{ type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: FeedbackWidgetHeaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "lib-feedback-widget-header",
                    templateUrl: "./feedback-widget-header.component.html",
                    styleUrls: ["./feedback-widget-header.component.scss"],
                }]
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; } });

class ProgressiveRatingComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
    onSelectChip(item) {
        const chips = this.fwService.currentState.chips;
        const index = chips.indexOf(item);
        let newChips = [];
        if (index === -1) {
            newChips = [...chips, item];
        }
        else {
            newChips = chips.filter((chip) => chip !== item);
        }
        this.fwService.updateUserFeedback({ chips: newChips });
    }
    getHeader() {
        const type = this.fwService.currentState.ratingInfo.type;
        const { badRatingHeader, averageRatingHeader, goodRatingHeader } = this.fwService.metaData;
        switch (type) {
            case RATING_TYPE.GOOD:
                return goodRatingHeader;
            case RATING_TYPE.AVERAGE:
                return averageRatingHeader;
            case RATING_TYPE.BAD:
                return badRatingHeader;
            default:
                return "";
        }
    }
    onFeedbackText(progressiveFeedbackData) {
        this.fwService.updateUserFeedback({ progressiveFeedbackData });
    }
}
ProgressiveRatingComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ProgressiveRatingComponent, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Component });
ProgressiveRatingComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: ProgressiveRatingComponent, selector: "lib-progressive-rating", ngImport: i0, template: "<div class=\"fw-progressive-rating\">\n  <p class=\"fw-header\">{{ getHeader() }}</p>\n  <div\n    class=\"fw-chips-container\"\n    *ngIf=\"fwService.metaData?.progressiveChips?.length\"\n  >\n    <div\n      class=\"fw-chip-item\"\n      [ngClass]=\"{ 'fw-active': fwService.currentState.chips.includes(item) }\"\n      *ngFor=\"let item of fwService.metaData.progressiveChips\"\n      (click)=\"onSelectChip(item)\"\n    >\n      {{ item }}\n    </div>\n  </div>\n  <div\n    class=\"fw-textarea\"\n    *ngIf=\"!fwService.metaData?.progressiveChips?.length\"\n  >\n    <textarea\n      rows=\"4\"\n      cols=\"100\"\n      placeholder=\"Tell us more (optional)\"\n      [maxLength]=\"fwService.metaData.textareaLimit\"\n      [value]=\"fwService.currentState.progressiveFeedbackData\"\n      (change)=\"onFeedbackText($event.target.value)\"\n    ></textarea>\n  </div>\n</div>\n", styles: [":host .fw-progressive-rating{margin:40px 0}:host .fw-progressive-rating .fw-header{font-weight:700;font-size:18px;line-height:24px;margin:0}:host .fw-progressive-rating .fw-chips-container{display:flex;flex-wrap:wrap;justify-content:space-between}:host .fw-progressive-rating .fw-chip-item{padding:15px 20px;font-size:15px;font-weight:700;border:1px solid #6a6a6d;border-radius:3px;cursor:pointer;width:calc(50% - 7.5px);box-sizing:border-box;margin-top:15px}:host .fw-progressive-rating .fw-chip-item.fw-active{background:#e3f2fd;color:#007ba8;border:1px solid #0b78d0}:host .fw-progressive-rating .fw-textarea{display:flex;margin-top:20px}:host .fw-progressive-rating .fw-textarea textarea{border:1px solid #6a6a6d;border-radius:3px;padding:10px;resize:none}\n"], directives: [{ type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ProgressiveRatingComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "lib-progressive-rating",
                    templateUrl: "./progressive-rating.component.html",
                    styleUrls: ["./progressive-rating.component.scss"],
                }]
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; } });

class FeedbackWidgetFooterComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
}
FeedbackWidgetFooterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: FeedbackWidgetFooterComponent, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Component });
FeedbackWidgetFooterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: FeedbackWidgetFooterComponent, selector: "lib-feedback-widget-footer", inputs: { fullWidth: "fullWidth", disabled: "disabled" }, ngImport: i0, template: "<div class=\"fw-footer-container\">\n  <button class=\"fw-submit-btn\" [ngClass]=\"{'fw-fullWidth': fullWidth, 'fw-disable': disabled, 'fw-active': !disabled}\" (click)=\"!disabled && fwService.metaData.onSubmitFeedback()\">{{ fwService.metaData.feedbackBtnText }}</button>\n</div>\n", styles: [":host .fw-footer-container{display:flex;align-items:center;justify-content:flex-end}:host .fw-footer-container .fw-submit-btn{width:200px;height:40px;border-radius:3px;font-weight:700;font-size:12px;line-height:21px;text-align:center;text-transform:uppercase;color:#fff;cursor:pointer}:host .fw-footer-container .fw-submit-btn.fw-active{background:#0b78d0;border:3px solid #0b78d0}:host .fw-footer-container .fw-submit-btn.fw-disable{background:#bebec1;border:3px solid #bebec1;cursor:not-allowed}:host .fw-footer-container .fw-submit-btn.fw-fullWidth{width:100%}\n"], directives: [{ type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: FeedbackWidgetFooterComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "lib-feedback-widget-footer",
                    templateUrl: "./feedback-widget-footer.component.html",
                    styleUrls: ["./feedback-widget-footer.component.scss"],
                }]
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; }, propDecorators: { fullWidth: [{
                type: Input
            }], disabled: [{
                type: Input
            }] } });

class StarFeedbackWidgetComponent {
    constructor(fwService) {
        this.fwService = fwService;
        this.ratingArr = STAR_RATINGS;
        this.starIcon = "assets/images/fw_starIcon.svg";
        this.starIconYellow = "assets/images/fw_starIconYellow.svg";
    }
    ngOnInit() { }
    onSelect(ratingInfo) {
        this.fwService.updateUserFeedback({ ratingInfo });
    }
}
StarFeedbackWidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: StarFeedbackWidgetComponent, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Component });
StarFeedbackWidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: StarFeedbackWidgetComponent, selector: "app-star-feedback-widget", ngImport: i0, template: "<div class=\"fw-dialog-container\" [style.width]=\"fwService.metaData.width\" [style.height]=\"fwService.metaData.height\">\n    <lib-feedback-widget-header></lib-feedback-widget-header>\n    <div class=\"fw-rating-container\">\n        <div class=\"fw-rating\" *ngFor=\"let item of ratingArr\" (click)=\"onSelect(item)\">\n            <img [src]=\"fwService.currentState.ratingInfo?.rating >= item.rating ? starIconYellow : starIcon\" />\n        </div>\n    </div>\n    <div class=\"fw-rating-info\" [hidden]=\"!fwService.currentState.ratingInfo\">\n        <img [src]=\"fwService.currentState.ratingInfo?.imgUrl\" />\n        <span [ngClass]=\"{'fw-green': fwService.currentState.ratingInfo?.rating > 2, 'fw-red': fwService.currentState.ratingInfo?.rating < 3}\">{{ fwService.currentState.ratingInfo?.title }}</span>\n    </div>\n    <lib-progressive-rating *ngIf=\"fwService.metaData.enableProgressive && fwService.currentState.ratingInfo\"></lib-progressive-rating>\n    <lib-feedback-widget-footer [fullWidth]=\"true\" [disabled]=\"!fwService.currentState.ratingInfo\"></lib-feedback-widget-footer>\n</div>\n", styles: [":host .fw-dialog-container{width:500px}:host .fw-dialog-container .fw-rating-container{display:flex;justify-content:space-between;margin:40px 0}:host .fw-dialog-container .fw-rating-container .fw-rating{display:flex;flex-direction:column;align-items:center;justify-content:center;cursor:pointer}:host .fw-dialog-container .fw-rating-container .fw-rating img{width:40px;height:38px}:host .fw-dialog-container .fw-rating-info{display:flex;align-items:center;justify-content:center;margin:40px 0}:host .fw-dialog-container .fw-rating-info span{margin-left:10px;font-weight:700;font-size:15px;line-height:21px}:host .fw-dialog-container .fw-rating-info span.fw-green{color:#5fb25c}:host .fw-dialog-container .fw-rating-info span.fw-red{color:#e53935}\n"], components: [{ type: FeedbackWidgetHeaderComponent, selector: "lib-feedback-widget-header" }, { type: ProgressiveRatingComponent, selector: "lib-progressive-rating" }, { type: FeedbackWidgetFooterComponent, selector: "lib-feedback-widget-footer", inputs: ["fullWidth", "disabled"] }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: StarFeedbackWidgetComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "app-star-feedback-widget",
                    templateUrl: "./star-feedback-widget.component.html",
                    styleUrls: ["./star-feedback-widget.component.scss"],
                }]
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; } });

class SmileyFeedbackWidgetComponent {
    constructor(fwService) {
        this.fwService = fwService;
        this.ratingArr = SMILEY_RATINGS;
    }
    ngOnInit() { }
    onSelect(ratingInfo) {
        this.fwService.updateUserFeedback({ ratingInfo });
    }
}
SmileyFeedbackWidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: SmileyFeedbackWidgetComponent, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Component });
SmileyFeedbackWidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: SmileyFeedbackWidgetComponent, selector: "app-smiley-feedback-widget", ngImport: i0, template: "<div class=\"fw-dialog-container\" [style.width]=\"fwService.metaData.width\" [style.height]=\"fwService.metaData.height\">\n    <lib-feedback-widget-header></lib-feedback-widget-header>\n    <div class=\"fw-rating-container\">\n        <div class=\"fw-rating\" *ngFor=\"let item of ratingArr\" [ngClass]=\"{'fw-active': fwService.currentState.ratingInfo?.title === item.title }\" (click)=\"onSelect(item)\">\n            <img [src]=\"item.imgUrl\" />\n            <label>{{item.title}}</label>\n        </div>\n    </div>\n    <lib-progressive-rating *ngIf=\"fwService.metaData.enableProgressive && fwService.currentState.ratingInfo\"></lib-progressive-rating>\n    <lib-feedback-widget-footer [disabled]=\"!fwService.currentState.ratingInfo\"></lib-feedback-widget-footer>\n</div>\n", styles: [":host .fw-dialog-container{width:650px}:host .fw-dialog-container .fw-rating-container{display:flex;justify-content:space-between;margin:40px 0}:host .fw-dialog-container .fw-rating-container .fw-rating{border:1px solid #6a6a6d;border-radius:3px;text-align:center;width:100px;height:100px;display:flex;flex-direction:column;align-items:center;justify-content:center;cursor:pointer}:host .fw-dialog-container .fw-rating-container .fw-rating img{width:30px;height:30px}:host .fw-dialog-container .fw-rating-container .fw-rating label{margin-top:10px;cursor:pointer}:host .fw-dialog-container .fw-rating-container .fw-rating.fw-active,:host .fw-dialog-container .fw-rating-container .fw-rating:hover{background:#e3f2fd;border:1px solid #0b78d0}\n"], components: [{ type: FeedbackWidgetHeaderComponent, selector: "lib-feedback-widget-header" }, { type: ProgressiveRatingComponent, selector: "lib-progressive-rating" }, { type: FeedbackWidgetFooterComponent, selector: "lib-feedback-widget-footer", inputs: ["fullWidth", "disabled"] }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: SmileyFeedbackWidgetComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "app-smiley-feedback-widget",
                    templateUrl: "./smiley-feedback-widget.component.html",
                    styleUrls: ["./smiley-feedback-widget.component.scss"],
                }]
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; } });

class FeedbackWidgetThankyouComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
    onDone() {
        this.fwService.metaData.closeHandler();
        this.fwService.metaData.successHandler();
    }
}
FeedbackWidgetThankyouComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: FeedbackWidgetThankyouComponent, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Component });
FeedbackWidgetThankyouComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: FeedbackWidgetThankyouComponent, selector: "lib-feedback-widget-thankyou", ngImport: i0, template: "<div class=\"fw-dialog-container\">\n  <p class=\"fw-header\">\n    <img src=\"assets/images/fw_greenTick.svg\" />\n    {{ fwService.metaData.thankYouHeading }}\n  </p>\n  <p class=\"fw-sub-header\">{{ fwService.metaData.thankYouDescription }}</p>\n  <img\n    *ngIf=\"fwService.metaData.showClose\"\n    class=\"fw-close-icon\"\n    (click)=\"fwService.metaData.closeHandler()\"\n    src=\"assets/images/fw_close_icon.svg\"\n  />\n  <div class=\"fw-footer-container\">\n    <button class=\"fw-submit-btn fw-active\" (click)=\"onDone()\">{{ fwService.metaData.thankYouBtnText }}</button>\n  </div>\n</div>\n", styles: [":host .fw-dialog-container{max-height:400px;width:400px}:host .fw-dialog-container .fw-header{font-weight:700;font-size:24px;line-height:33px;color:#5fb25c;display:flex;align-items:center}:host .fw-dialog-container .fw-header img{margin-right:15px}:host .fw-dialog-container .fw-sub-header{font-weight:400;font-size:15px;line-height:21px}:host .fw-dialog-container .fw-close-icon{position:absolute;top:10px;right:10px;width:21px;height:21px;cursor:pointer}:host .fw-dialog-container .fw-footer-container{display:flex;align-items:center;justify-content:flex-end;margin-top:40px}:host .fw-dialog-container .fw-footer-container .fw-submit-btn{width:125px;height:40px;border-radius:3px;font-weight:700;font-size:12px;line-height:21px;text-align:center;text-transform:uppercase;color:#fff;cursor:pointer}:host .fw-dialog-container .fw-footer-container .fw-submit-btn.fw-active{background:#0b78d0;border:3px solid #0b78d0}\n"], directives: [{ type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: FeedbackWidgetThankyouComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "lib-feedback-widget-thankyou",
                    templateUrl: "./feedback-widget-thankyou.component.html",
                    styleUrls: ["./feedback-widget-thankyou.component.scss"],
                }]
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; } });

class DpwFeedbackWidgetComponent {
    constructor(fwService) {
        this.fwService = fwService;
        this.feedbackBtnText = DEFAULT_FEEDBACK_META_DATA.feedbackBtnText;
        this.showClose = DEFAULT_FEEDBACK_META_DATA.showClose;
        this.thankYouBtnText = DEFAULT_FEEDBACK_META_DATA.thankYouBtnText;
        this.badRatingHeader = DEFAULT_FEEDBACK_META_DATA.badRatingHeader;
        this.averageRatingHeader = DEFAULT_FEEDBACK_META_DATA.averageRatingHeader;
        this.goodRatingHeader = DEFAULT_FEEDBACK_META_DATA.goodRatingHeader;
        this.onClose = new EventEmitter();
        this.onSuccess = new EventEmitter();
        this.textareaLimit = DEFAULT_FEEDBACK_META_DATA.textareaLimit;
        this.feedbackSubmitted = false;
        this.closeHandler = () => {
            this.onClose.emit();
        };
        this.successHandler = () => {
            this.onSuccess.emit();
        };
        this.onSubmitFeedback = () => {
            const { ratingInfo, progressiveFeedbackData, chips } = this.fwService.currentState;
            const data = {
                userEmail: this.userEmail || "",
                isUserLoggedOut: this.isLoggedIn,
                ratingScore: ratingInfo.rating,
                progessiveChipsSelected: chips && chips.length ? JSON.stringify(chips) : null,
                progressiveFeedbackData,
            };
            console.log("sourabh data: ", data);
            // this.fwService.submitFeedback(data).subscribe((res) => {
            //   this.feedbackSubmitted = true;
            // });
            this.feedbackSubmitted = true;
        };
    }
    ngOnInit() {
        const { width, height, widgetName, productName, heading, description, ratingStyle, feedbackBtnText, showClose, thankYouHeading, thankYouDescription, thankYouBtnText, enableProgressive, progressiveChips, badRatingHeader, averageRatingHeader, goodRatingHeader, isLoggedIn, textareaLimit, closeHandler, onSubmitFeedback, successHandler, } = this;
        this.fwService.updateMetaData({
            width,
            height,
            widgetName,
            productName,
            header: heading,
            subHeader: description,
            ratingStyle,
            feedbackBtnText,
            showClose,
            thankYouHeading,
            thankYouDescription,
            thankYouBtnText,
            enableProgressive: isLoggedIn && enableProgressive,
            progressiveChips,
            badRatingHeader,
            averageRatingHeader,
            goodRatingHeader,
            textareaLimit,
            closeHandler,
            onSubmitFeedback,
            successHandler,
        });
    }
    ngOnDestroy() {
        this.fwService.resetState();
    }
}
DpwFeedbackWidgetComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetComponent, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Component });
DpwFeedbackWidgetComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: DpwFeedbackWidgetComponent, selector: "dpw-feedback-widget", inputs: { width: "width", height: "height", widgetName: "widgetName", productName: "productName", heading: "heading", description: "description", ratingStyle: "ratingStyle", userEmail: "userEmail", isLoggedIn: "isLoggedIn", feedbackBtnText: "feedbackBtnText", showClose: "showClose", thankYouHeading: "thankYouHeading", thankYouDescription: "thankYouDescription", thankYouBtnText: "thankYouBtnText", enableProgressive: "enableProgressive", progressiveChips: "progressiveChips", badRatingHeader: "badRatingHeader", averageRatingHeader: "averageRatingHeader", goodRatingHeader: "goodRatingHeader", textareaLimit: "textareaLimit" }, outputs: { onClose: "onClose", onSuccess: "onSuccess" }, ngImport: i0, template: "<div class=\"feedback-widget-container\" *ngIf=\"!fwService.hasError\">\n  <ng-container\n    [ngSwitch]=\"ratingStyle.toUpperCase()\"\n    *ngIf=\"!feedbackSubmitted; else thankyou\"\n  >\n    <ng-container *ngSwitchCase=\"'STAR'\">\n      <app-star-feedback-widget></app-star-feedback-widget>\n    </ng-container>\n    <ng-container *ngSwitchCase=\"'SMILEY'\">\n      <app-smiley-feedback-widget></app-smiley-feedback-widget>\n    </ng-container>\n  </ng-container>\n  <ng-template #thankyou>\n    <lib-feedback-widget-thankyou></lib-feedback-widget-thankyou>\n  </ng-template>\n</div>\n", styles: [":host .feedback-widget-container{position:fixed;z-index:99999999;background:rgba(0,0,0,.5);width:100%;height:100%;top:0;left:0;bottom:0;right:0}:host ::ng-deep .fw-dialog-container{background:#ffffff;border-radius:3px 3px 0 0;padding:40px;box-sizing:border-box;overflow:auto;position:absolute;left:50%;top:50%;transform:translate(-50%,-50%)}\n"], components: [{ type: StarFeedbackWidgetComponent, selector: "app-star-feedback-widget" }, { type: SmileyFeedbackWidgetComponent, selector: "app-smiley-feedback-widget" }, { type: FeedbackWidgetThankyouComponent, selector: "lib-feedback-widget-thankyou" }], directives: [{ type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { type: i5.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }] });
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "width", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "height", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "widgetName", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "productName", void 0);
__decorate([
    isRequired("string", 100)
], DpwFeedbackWidgetComponent.prototype, "heading", void 0);
__decorate([
    isRequired("string", 200)
], DpwFeedbackWidgetComponent.prototype, "description", void 0);
__decorate([
    isRequired("string")
], DpwFeedbackWidgetComponent.prototype, "ratingStyle", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "userEmail", void 0);
__decorate([
    isRequired("boolean")
], DpwFeedbackWidgetComponent.prototype, "isLoggedIn", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "feedbackBtnText", void 0);
__decorate([
    validateAgainst(isTypeOf("boolean"))
], DpwFeedbackWidgetComponent.prototype, "showClose", void 0);
__decorate([
    isRequired("string", 100)
], DpwFeedbackWidgetComponent.prototype, "thankYouHeading", void 0);
__decorate([
    isRequired("string", 200)
], DpwFeedbackWidgetComponent.prototype, "thankYouDescription", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "thankYouBtnText", void 0);
__decorate([
    validateAgainst(isTypeOf("boolean"))
], DpwFeedbackWidgetComponent.prototype, "enableProgressive", void 0);
__decorate([
    validateAgainst(isTypeOf("array", 4))
], DpwFeedbackWidgetComponent.prototype, "progressiveChips", void 0);
__decorate([
    validateAgainst(isTypeOf("string", 50))
], DpwFeedbackWidgetComponent.prototype, "badRatingHeader", void 0);
__decorate([
    validateAgainst(isTypeOf("string", 50))
], DpwFeedbackWidgetComponent.prototype, "averageRatingHeader", void 0);
__decorate([
    validateAgainst(isTypeOf("string", 50))
], DpwFeedbackWidgetComponent.prototype, "goodRatingHeader", void 0);
__decorate([
    validateAgainst(isTypeOf("number"))
], DpwFeedbackWidgetComponent.prototype, "textareaLimit", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "dpw-feedback-widget",
                    templateUrl: "./dpw-feedback-widget.component.html",
                    styleUrls: ["./dpw-feedback-widget.component.scss"],
                }]
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; }, propDecorators: { width: [{
                type: Input
            }], height: [{
                type: Input
            }], widgetName: [{
                type: Input
            }], productName: [{
                type: Input
            }], heading: [{
                type: Input
            }], description: [{
                type: Input
            }], ratingStyle: [{
                type: Input
            }], userEmail: [{
                type: Input
            }], isLoggedIn: [{
                type: Input
            }], feedbackBtnText: [{
                type: Input
            }], showClose: [{
                type: Input
            }], thankYouHeading: [{
                type: Input
            }], thankYouDescription: [{
                type: Input
            }], thankYouBtnText: [{
                type: Input
            }], enableProgressive: [{
                type: Input
            }], progressiveChips: [{
                type: Input
            }], badRatingHeader: [{
                type: Input
            }], averageRatingHeader: [{
                type: Input
            }], goodRatingHeader: [{
                type: Input
            }], onClose: [{
                type: Output
            }], onSuccess: [{
                type: Output
            }], textareaLimit: [{
                type: Input
            }] } });

class GlobalErrorHandler {
    constructor(fwService) {
        this.fwService = fwService;
    }
    handleError(error) {
        this.fwService.hasError = true;
        throw new Error(error);
    }
}
GlobalErrorHandler.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: GlobalErrorHandler, deps: [{ token: DpwFeedbackWidgetService }], target: i0.ɵɵFactoryTarget.Injectable });
GlobalErrorHandler.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: GlobalErrorHandler });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: GlobalErrorHandler, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: DpwFeedbackWidgetService }]; } });

class DpwFeedbackWidgetModule {
}
DpwFeedbackWidgetModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DpwFeedbackWidgetModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetModule, declarations: [DpwFeedbackWidgetComponent,
        StarFeedbackWidgetComponent,
        SmileyFeedbackWidgetComponent,
        FeedbackWidgetHeaderComponent,
        FeedbackWidgetFooterComponent,
        FeedbackWidgetThankyouComponent,
        ProgressiveRatingComponent], imports: [CommonModule], exports: [DpwFeedbackWidgetComponent] });
DpwFeedbackWidgetModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetModule, providers: [{ provide: ErrorHandler, useClass: GlobalErrorHandler }], imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: DpwFeedbackWidgetModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        DpwFeedbackWidgetComponent,
                        StarFeedbackWidgetComponent,
                        SmileyFeedbackWidgetComponent,
                        FeedbackWidgetHeaderComponent,
                        FeedbackWidgetFooterComponent,
                        FeedbackWidgetThankyouComponent,
                        ProgressiveRatingComponent,
                    ],
                    imports: [CommonModule],
                    exports: [DpwFeedbackWidgetComponent],
                    providers: [{ provide: ErrorHandler, useClass: GlobalErrorHandler }],
                }]
        }] });

/*
 * Public API Surface of dpw-feedback-widget
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DpwFeedbackWidgetComponent, DpwFeedbackWidgetModule, DpwFeedbackWidgetService };
//# sourceMappingURL=dpw-feedback-widget.js.map
